@@ -5,8 +5,8 @@ Options
 """
 
 from collections import OrderedDict
-import babelfish
 
+import babelfish
 import yaml  # pylint:disable=wrong-import-order
 
 from .rules.common.quantity import BitRate, FrameRate, Size
@@ -35,7 +35,7 @@ class OrderedDictYAMLLoader(yaml.SafeLoader):
             self.flatten_mapping(node)
         else:  # pragma: no cover
             raise yaml.constructor.ConstructorError(None, None,
-                                                    'expected a mapping node, but found %s' % node.id, node.start_mark)
+                                                    f'expected a mapping node, but found {node.id}', node.start_mark)
 
         mapping = OrderedDict()
         for key_node, value_node in node.value:
@@ -44,8 +44,8 @@ class OrderedDictYAMLLoader(yaml.SafeLoader):
                 hash(key)
             except TypeError as exc:  # pragma: no cover
                 raise yaml.constructor.ConstructorError('while constructing a mapping',
-                                                        node.start_mark, 'found unacceptable key (%s)'
-                                                        % exc, key_node.start_mark)
+                                                        node.start_mark, f'found unacceptable key ({exc})'
+                                                        , key_node.start_mark)
             value = self.construct_object(value_node, deep=deep)
             mapping[key] = value
         return mapping
